/**************************************************************************
/* This class lists all available scripting-engines.
/*
/* Copyright (c) 2007 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

import java.util.*;
import javax.script.*;

/**
   This class lists all available scripting-engines.

   @version $Revision: 1.3 $
   @author  $Author: bablokb $
*/

public class ListEngines{
  
  //////////////////////////////////////////////////////////////////////////////

  /**
     Constructor.
  */

  public ListEngines() {
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Main method.

     @param args Program arguments (ignored).
  */

  public static void main(String[] args) {
      ScriptEngineManager manager = new ScriptEngineManager();

      System.out.println("ScriptEngineFactories:");

      List<ScriptEngineFactory> factories = manager.getEngineFactories();
      for (ScriptEngineFactory factory: factories) {
	String engName     = factory.getEngineName();
	String engVersion  = factory.getEngineVersion();
	String langName    = factory.getLanguageName();
	String langVersion = factory.getLanguageVersion();
	System.out.printf("\n Script Engine: %s (%s)\n" +
	                  "  Language:     %s (%s)\n", 
			              engName,engVersion,langName,langVersion);

	List<String> aliasList = factory.getNames();
	for(String alias: aliasList) {
	  System.out.printf("  Engine Alias: %s\n", alias);
	}

	List<String> extList = factory.getExtensions();
	for(String ext: extList) {
	  System.out.printf("  Extension:    %s\n", ext);
	}
      }
  }
}
